/* DESCRIPTION
 * Exemple de 'sketch' pour contrôler 2 relais   (broche 4 et 5)
 * http://www.mysensors.org/build/relay
 */

// Activer les sorties de débogage sur le moniteur série
#define MY_DEBUG
// Activer et sélectionner le type de radio attaché
#define MY_RADIO_RF24
#include <MySensors.h>
#include <Adafruit_SHT31.h>

#define RELAY_PIN 4  // Numéro de broche Digital pour le premier relais (le deuxième sur la broche + 1, etc.)
#define NUMBER_OF_RELAYS 2 // Nombre total de relais connectés
#define RELAY_ON 1  // Valeur à écrire pour activer le relais connecté
#define RELAY_OFF 0  // Valeur GPIO à écrire pour désactiver le relais connecté
#define CHILD_ID_TEMP         3
#define CHILD_ID_HUM          4
#define COMPARE_TEMP          0
#define dtm 20000L   //20s  entre les mesures

Adafruit_SHT31 sht31 = Adafruit_SHT31();
long tenv  = 0;

void before()
{
	for (int sensor=1, pin=RELAY_PIN; sensor<=NUMBER_OF_RELAYS; sensor++, pin++) {
		pinMode(pin, OUTPUT);// Mettre les broches de relais en mode sortie
		digitalWrite(pin,RELAY_OFF);
	}
    Serial.print("MYSENSORS SHT31D Temperature Humidity sensor: ");
    // Startup up the SHT31 library
    Serial.println(F("Start SHT31"));
    if (!sht31.begin(0x44)) {
        Serial.println(F("Couldn't find SHT31"));
    }
    Serial.println("SHT31 OK");

}

void presentation()
{
	// Envoyer les informations à la passerelle et au contrôleur
	sendSketchInfo("Relais, temp, humid", "1.0");
	for (int sensor=1, pin=RELAY_PIN; sensor<=NUMBER_OF_RELAYS; sensor++, pin++) {
	// Enregistrer tous les capteurs  (ils seront créés en tant que dispositifs enfants)
		present(sensor, S_BINARY);
	}
    present(CHILD_ID_TEMP, S_TEMP);
    present(CHILD_ID_HUM, S_HUM);
}
void readSHT31D(void)
{
  MyMessage tempMsg(0,V_TEMP);
  MyMessage humMsg(0,V_HUM);
  static float lastTemperature;
  
  float temperature = sht31.readTemperature();
  float humidity = sht31.readHumidity();

  #if COMPARE_TEMP == 1
  if (lastTemperature != temperature && !isnan(temperature)) {
  #else
  if (!isnan(temperature)) {
  #endif
    // Send in the new temperature
    send(tempMsg.setSensor(CHILD_ID_TEMP).set(temperature, 1));
    send(humMsg.setSensor(CHILD_ID_HUM).set(humidity, 1));
    // Save new temperatures for next compare
    lastTemperature = temperature;
    Serial.print("transmitted temperature OK: ");
    Serial.print(temperature, 2);
    Serial.println("°C");
    Serial.print("transmitted humidity OK: ");
    Serial.print(humidity, 2);
    Serial.println("%");
    delay(10);
  }
}
void loop()
{ 
  if (millis()>tenv)  {
      readSHT31D();
      tenv+=dtm;
  }
}

void receive(const MyMessage &message)
{
	// Nous n'attendons qu'un seul type de message du contrôleur. Mais nous ferions mieux de vérifier de toute façon.
	if (message.getType()==V_STATUS) {
		// Changer l'état du relais
		digitalWrite(message.getSensor()-1+RELAY_PIN, message.getBool()?RELAY_ON:RELAY_OFF);
		// Écrire des informations de débogage
		Serial.print("Changement entrant : pour le capteur:");
		Serial.print(message.getSensor());
		Serial.print(", Nouveau statut : ");
		Serial.println(message.getBool());
	}
}
